## Summary

<!-- What does this PR do? 1-3 bullet points -->
-

## Type of Change

- [ ] Bug fix
- [ ] New feature
- [ ] Refactoring
- [ ] Documentation
- [ ] CI/CD
- [ ] Breaking change

## Testing

- [ ] Existing tests pass (`make test`)
- [ ] New tests added for new functionality
- [ ] `make pre-push` passes

## Checklist

- [ ] CHANGELOG.md updated under `[Unreleased]`
- [ ] Documentation updated if needed
- [ ] No new security vulnerabilities introduced
